Module texcraft

Module texcraft 

The Texcraft primitive, which returns the word Texcraft as eight separate letter tokens

This primitive is essentially equivalent to \def\Texcraft{Texcraft}. It was implemented to be a simple example of a custom expansion primitive.

Functions

get_texcraft
Get the \texcraft expansion primitive.
texcraft_primitive_fn